@@ -24,11 +24,6 @@
 #include <KPluginMetaData>
 #include <KSharedConfig>
 
-#include "config.h"
-#if HAVE_KACTIVITIES
-#include <KActivities/Consumer>
-#endif
-
 #include "abstractrunner_p.h"
 #include "dbusrunner_p.h"
 #include "kpluginmetadata_utils_p.h"
@@ -96,19 +91,7 @@ public:
 
     void loadConfiguration()
     {
-#if HAVE_KACTIVITIES
-        // Wait for consumer to be ready
-        QObject::connect(&activitiesConsumer,
-                         &KActivities::Consumer::serviceStatusChanged,
-                         &activitiesConsumer,
-                         [this](KActivities::Consumer::ServiceStatus status) {
-                             if (status == KActivities::Consumer::Running) {
-                                 deleteHistoryOfDeletedActivities();
-                             }
-                         });
-#endif
         const KConfigGroup generalConfig = pluginConf.config()->group(QStringLiteral("General"));
-        activityAware = generalConfig.readEntry("ActivityAware", true);
         context.restore(stateData);
     }
 
@@ -297,9 +280,6 @@ public:
         bool matchesRegex = singleMode || !runner->hasMatchRegex() || runner->matchRegex().match(query).hasMatch();
 
         if (matchesCount && matchesRegex) {
-            if (allRunnersPrepped) {
-                Q_EMIT runner->prepare();
-            }
             startJob(runner);
         } else {
             onRunnerJobFinished(jobId);
@@ -338,17 +318,6 @@ public:
         });
     }
 
-    inline QString getActivityKey()
-    {
-#if HAVE_KACTIVITIES
-        if (activityAware) {
-            const QString currentActivity = activitiesConsumer.currentActivity();
-            return currentActivity.isEmpty() ? nulluuid : currentActivity;
-        }
-#endif
-        return nulluuid;
-    }
-
     void addToHistory()
     {
         const QString term = context.query();
@@ -356,7 +325,7 @@ public:
         if (!historyEnabled || term.isEmpty() || untrimmedTerm.startsWith(QLatin1Char(' '))) {
             return;
         }
-        QStringList historyEntries = readHistoryForCurrentActivity();
+        QStringList historyEntries = readHistoryForCurrentEnv();
         // Avoid removing the same item from the front and prepending it again
         if (!historyEntries.isEmpty() && historyEntries.constFirst() == term) {
             return;
@@ -368,40 +337,21 @@ public:
         while (historyEntries.count() > 50) { // we don't want to store more than 50 entries
             historyEntries.removeLast();
         }
-        writeActivityHistory(historyEntries);
+        writeHistory(historyEntries);
     }
 
-    void writeActivityHistory(const QStringList &historyEntries)
+    void writeHistory(const QStringList &historyEntries)
     {
-        stateData.group(QStringLiteral("History")).writeEntry(getActivityKey(), historyEntries, KConfig::Notify);
+        stateData.group(QStringLiteral("History")).writeEntry(historyEnvironmentIdentifier, historyEntries, KConfig::Notify);
         stateData.sync();
     }
 
-#if HAVE_KACTIVITIES
-    void deleteHistoryOfDeletedActivities()
+    inline QStringList readHistoryForCurrentEnv()
     {
-        KConfigGroup historyGroup = stateData.group(QStringLiteral("History"));
-        QStringList historyEntries = historyGroup.keyList();
-        historyEntries.removeOne(nulluuid);
-
-        // Check if history still exists
-        const QStringList activities = activitiesConsumer.activities();
-        for (const auto &a : activities) {
-            historyEntries.removeOne(a);
-        }
-
-        for (const QString &deletedActivity : std::as_const(historyEntries)) {
-            historyGroup.deleteEntry(deletedActivity);
-        }
-        historyGroup.sync();
-    }
-#endif
-
-    inline QStringList readHistoryForCurrentActivity()
-    {
-        return stateData.group(QStringLiteral("History")).readEntry(getActivityKey(), QStringList());
+        return stateData.group(QStringLiteral("History")).readEntry(historyEnvironmentIdentifier, QStringList());
     }
 
+    QString historyEnvironmentIdentifier = QStringLiteral("default");
     RunnerManager *const q;
     RunnerContext context;
     QTimer matchChangeTimer;
@@ -415,18 +365,13 @@ public:
     bool allRunnersPrepped = false;
     bool singleRunnerPrepped = false;
     bool singleMode = false;
-    bool activityAware = false;
     bool historyEnabled = true;
     QStringList whiteList;
     KConfigWatcher::Ptr watcher;
     QString untrimmedTerm;
-    const QString nulluuid = QStringLiteral("00000000-0000-0000-0000-000000000000");
     KConfigGroup pluginConf;
     KConfigGroup stateData;
     QSet<QString> disabledRunnerIds; // Runners that are disabled but were loaded as single runners
-#if HAVE_KACTIVITIES
-    const KActivities::Consumer activitiesConsumer;
-#endif
 };
 
 RunnerManager::RunnerManager(const KConfigGroup &pluginConfigGroup, KConfigGroup stateConfigGroup, QObject *parent)
@@ -576,8 +521,7 @@ void RunnerManager::setupMatchSession()
         }
     } else {
         for (AbstractRunner *runner : std::as_const(d->runners)) {
-            // In case it is suspended, we will emit prepare when it resumed
-            if (!d->disabledRunnerIds.contains(runner->name()) && !runner->isMatchingSuspended()) {
+            if (!d->disabledRunnerIds.contains(runner->name())) {
                 Q_EMIT runner->prepare();
             }
         }
@@ -601,7 +545,6 @@ void RunnerManager::matchSessionComplete()
 void RunnerManager::launchQuery(const QString &untrimmedTerm, const QString &runnerName)
 {
     d->pendingJobsAfterSuspend.clear(); // Do not start old jobs when we got a new query
-    setupMatchSession();
     QString term = untrimmedTerm.trimmed();
     const QString prevSingleRunner = d->singleModeRunnerId;
     d->untrimmedTerm = untrimmedTerm;
@@ -645,6 +588,7 @@ void RunnerManager::launchQuery(const QString &untrimmedTerm, const QString &run
 
     qint64 startTs = QDateTime::currentMSecsSinceEpoch();
     d->context.setJobStartTs(startTs);
+    setupMatchSession();
     for (KRunner::AbstractRunner *r : std::as_const(runnable)) {
         const QString &jobId = d->context.runnerJobId(r);
         if (r->isMatchingSuspended()) {
@@ -687,7 +631,7 @@ QString RunnerManager::query() const
 
 QStringList RunnerManager::history() const
 {
-    return d->readHistoryForCurrentActivity();
+    return d->readHistoryForCurrentEnv();
 }
 
 void RunnerManager::removeFromHistory(int index)
@@ -695,7 +639,7 @@ void RunnerManager::removeFromHistory(int index)
     QStringList changedHistory = history();
     if (index < changedHistory.length()) {
         changedHistory.removeAt(index);
-        d->writeActivityHistory(changedHistory);
+        d->writeHistory(changedHistory);
     }
 }
 
@@ -740,6 +684,11 @@ void RunnerManager::onMatchesChanged()
 {
     d->scheduleMatchesChanged();
 }
+void RunnerManager::setHistoryEnvironmentIdentifier(const QString &identifier)
+{
+    Q_ASSERT(!identifier.isEmpty());
+    d->historyEnvironmentIdentifier = identifier;
+}
 
 } // KRunner namespace
 
